@@ -1,6 +1,7 @@
 use crate::sparse_graph::SparseGraph;
 
 use std::cmp::Ord;
+use std::hash::Hash;
 
 use nauty_Traces_sys::{
     optionblk, sparsegraph, sparsenauty, statsblk, Traces, TracesOptions,
@@ -43,7 +44,7 @@ pub trait TryIntoCanonTraces {
 impl<N, E, Ix: IndexType> IntoCanon for UnGraph<N, E, Ix>
 where
     N: Ord,
-    E: Ord,
+    E: Hash + Ord,
 {
     fn into_canon(self) -> Self {
         match self.try_into_canon_traces() {
@@ -56,7 +57,7 @@ where
 impl<N, E, Ix: IndexType> IntoCanon for DiGraph<N, E, Ix>
 where
     N: Ord,
-    E: Ord,
+    E: Hash + Ord,
 {
     fn into_canon(self) -> Self {
         self.into_canon_nauty_sparse()
@@ -66,7 +67,7 @@ where
 impl<N, E, Ty, Ix: IndexType> IntoCanonNautySparse for Graph<N, E, Ty, Ix>
 where
     N: Ord,
-    E: Ord,
+    E: Hash + Ord,
     Ty: EdgeType,
 {
     fn into_canon_nauty_sparse(self) -> Self {
@@ -75,14 +76,14 @@ where
         options.defaultptn = FALSE;
         options.digraph = TRUE;
         let mut stats = statsblk::default();
-        let mut orbits = vec![0; self.node_count()];
         let mut sg = SparseGraph::from(self);
+        let mut orbits = vec![0; sg.g.v.len()];
         let mut cg = sparsegraph::default();
         unsafe {
             sparsenauty(
                 &mut (&mut sg.g).into(),
-                sg.node_weights.lab.as_mut_ptr(),
-                sg.node_weights.ptn.as_mut_ptr(),
+                sg.nodes.lab.as_mut_ptr(),
+                sg.nodes.ptn.as_mut_ptr(),
                 orbits.as_mut_ptr(),
                 &mut options,
                 &mut stats,
@@ -97,7 +98,7 @@ where
 impl<N, E, Ix: IndexType> TryIntoCanonTraces for UnGraph<N, E, Ix>
 where
     N: Ord,
-    E: Ord,
+    E: Hash + Ord,
 {
     type Error = TracesError<N, E, Ix>;
 
@@ -112,14 +113,14 @@ where
             ..Default::default()
         };
         let mut stats = TracesStats::default();
-        let mut orbits = vec![0; self.node_count()];
         let mut sg = SparseGraph::from(self);
+        let mut orbits = vec![0; sg.g.v.len()];
         let mut cg = sparsegraph::default();
         unsafe {
             Traces(
                 &mut (&mut sg.g).into(),
-                sg.node_weights.lab.as_mut_ptr(),
-                sg.node_weights.ptn.as_mut_ptr(),
+                sg.nodes.lab.as_mut_ptr(),
+                sg.nodes.ptn.as_mut_ptr(),
                 orbits.as_mut_ptr(),
                 &mut options,
                 &mut stats,
@@ -153,7 +154,7 @@ mod tests {
         graph::{Graph, IndexType},
         Directed, EdgeType, Undirected,
     };
-    use rand::{distributions::Uniform, prelude::*};
+    use rand::prelude::*;
     use testing::GraphIter;
 
     use rand_xoshiro::Xoshiro256Plus;
@@ -234,8 +235,7 @@ mod tests {
         log_init();
 
         let mut rng = Xoshiro256Plus::seed_from_u64(0);
-        let mut graphs = GraphIter::<Undirected>::default();
-        graphs.edge_wt_distr = Uniform::from(0..=0);
+        let graphs = GraphIter::<Undirected>::default();
 
         for g in graphs.take(1000) {
             debug!("Initial graph: {g:#?}");
@@ -257,8 +257,7 @@ mod tests {
         log_init();
 
         let mut rng = Xoshiro256Plus::seed_from_u64(0);
-        let mut graphs = GraphIter::<Directed>::default();
-        graphs.edge_wt_distr = Uniform::from(0..=0);
+        let graphs = GraphIter::<Directed>::default();
 
         for g in graphs.take(700) {
             debug!("Initial graph: {g:#?}");
