@@ -13,7 +13,7 @@
 //! Afterwards, add this to your Cargo.toml:
 //! ```toml
 //! [dependencies]
-//! nauty-pet = "0.3"
+//! nauty-pet = "0.4"
 //! ```
 //!
 //! # Example
@@ -26,17 +26,16 @@
 //! let g1 = UnGraph::<(), ()>::from_edges([(0, 1), (1, 2)]);
 //! let g2 = UnGraph::<(), ()>::from_edges([(0, 1), (0, 2)]);
 //!
+//! // There are two equivalent labellings
+//! let automorphism_info = g1.clone().try_into_autom().unwrap();
+//! assert_eq!(automorphism_info.grpsize(), 2.);
+//!
+//! // The canonical forms are identical
 //! let c1 = g1.into_canon();
 //! let c2 = g2.into_canon();
 //! assert!(c1.is_identical(&c2))
 //! ```
-//!
-//! # Caveats
-//!
-//! Edge weights are not considered when finding a canonical form. In
-//! general, the canonical form is only unique if all edge weights are
-//! the same.
-//!
+mod autom;
 mod canon;
 mod cmp;
 pub mod prelude;
